<?php
/**
 * $Horde: jonah/content.php,v 1.36 2005/08/24 05:39:12 selsky Exp $
 *
 * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
 * Copyright 2002-2005 Eric Rechlin <eric@hpcalc.org>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/jonah/LICENSE.
 */

@define('JONAH_BASE', dirname(__FILE__));
require_once JONAH_BASE . '/lib/base.php';
require_once JONAH_BASE . '/lib/News.php';

/* Set up the news object. */
$news = &Jonah_News::singleton();

/* Fetch subscribed channels. */
$subscribed = $news->getSubscribedChannels();
if (!$subscribed || !is_array($subscribed)) {
    $subscribed = array();
}
$num_channels = count($subscribed);

/* Get number of columns to display. */
$cols = $prefs->getValue('columns');

/* Check if the number of channels is less than the number of columns. If so
 * set the columns to display to the number of channels. Avoids blank
 * columns. */
if ($num_channels < $cols) {
    $cols = $num_channels;
}

$count = 0;
$col = 0;
$unsubscribed = array();
$columns = array();

/* Loop through the channels and set up the array. */
foreach ($subscribed as $channel_id => $subscribed_channel) {
    if (!($count % $cols)) {
        /* Reached the max number of columns, start over so that the next
         * channel will be displayed in the first column. */
        $col = 0;
    }
    $channel = $news->getChannel($channel_id);
    if (is_a($channel, 'PEAR_Error')) {
        /* There was an error fetching this channel, probably because it is
         * no longer available. Channel will be marked for forced
         * unsubscription. */
        $columns[$col]['channels'][] = sprintf(_("Subscribed channel \"%s\" is no longer available, it will be removed from your subscriptions."), $subscribed_channel['channel_name']);
        $unsubscribed[] = $channel_id;
    } else {
        $columns[$col]['channels'][] = $news->renderChannel($channel_id, $subscribed_channel['view'], null);
    }

    $count++;
    $col++;
}

/* Check if any channels have been marked for forced unsubscribing. */
if (count($unsubscribed)) {
    foreach ($unsubscribed as $id) {
        unset($subscribed[$id]);
    }
    Jonah::prefEncode('channel_list', $subscribed);
}

/* Set up the template tags. */
$template = &new Horde_Template();
$template->set('colwidth', ($cols == 0 ? '100' : round(100 / $cols)));
$template->set('columns', $columns, true);
$template->set('menu', Jonah::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

$title = _("Channel Listing");
require JONAH_TEMPLATES . '/common-header.inc';
echo $template->fetch(JONAH_TEMPLATES . '/content/content.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
